import secrets

from flask import Flask, flash, redirect, render_template, request, session, url_for
from markupsafe import escape

import host_lookup
import upload

app = Flask(__name__)
generate_secret = secrets.token_urlsafe(16)
app.secret_key = generate_secret


@app.route("/")
def index():
    return redirect(url_for("lookup"))


@app.route("/lookup", methods=["GET", "POST"])
def lookup():
    hosts = []
    results = []
    if request.method == "GET":
        return render_template("lookup.html")
    elif request.method == "POST" and "host" in request.form:
        user_input = escape(request.form.get("host").strip())
        hosts, errors = host_lookup.process_input(user_input)
        for host in hosts:
            result = host_lookup.Lookedup(host)
            results.append(result)
        return render_template("results.html", hosts=results, errors=errors)
    elif request.method == "POST" and "file" in request.files:
        file = request.files["file"]
        extracted = upload.extract(file)
        hosts = host_lookup.process_file(extracted)
        return render_template("results.html", hosts=hosts)


if __name__ == "__main__":
    app.run(debug=True)
